﻿namespace Mud.Helpers
{
	using System.Windows.Media;

	public class Logging
	{
		public static void Write(LogLevel level, string message, params object[] args)
		{
			ff14bot.Helpers.Logging.Write(level.GetLight(), $"[MudAssist] {message}", args);
		}

		public static void Write(string message, params object[] args)
		{
			Write(LogLevel.INFO, message, args);
		}
	}

	public class LogLevel
	{
		public static LogLevel DANGER = new LogLevel(Color.FromRgb(239, 83, 80), Color.FromRgb(213, 0, 0));
		public static LogLevel INFO = new LogLevel(Color.FromRgb(171, 71, 188), Color.FromRgb(74, 20, 140));
		public static LogLevel PRIMARY = new LogLevel(Color.FromRgb(30, 150, 243), Color.FromRgb(21, 101, 192));
		public static LogLevel SUCCESS = new LogLevel(Color.FromRgb(60, 179, 113), Color.FromRgb(34, 139, 87));
		public static LogLevel WARNING = new LogLevel(Color.FromRgb(255, 140, 0), Color.FromRgb(255, 127, 80));

		private Color dark;
		private System.Drawing.Color drawingDark;
		private System.Drawing.Color drawingLight;
		private Color light;

		public LogLevel(Color light, Color dark)
		{
			SetLight(light);
			SetDark(dark);
			SetDrawingLight(System.Drawing.Color.FromArgb(GetLight().A, GetLight().R, GetLight().G, GetLight().B));
			SetDrawingDark(System.Drawing.Color.FromArgb(GetDark().A, GetDark().R, GetDark().G, GetDark().B));
		}

		public Color GetDark()
		{
			return dark;
		}

		public System.Drawing.Color GetDrawingDark()
		{
			return drawingDark;
		}

		public System.Drawing.Color GetDrawingLight()
		{
			return drawingLight;
		}

		public Color GetLight()
		{
			return light;
		}

		private void SetDark(Color value)
		{
			dark = value;
		}

		private void SetDrawingDark(System.Drawing.Color value)
		{
			drawingDark = value;
		}

		private void SetDrawingLight(System.Drawing.Color value)
		{
			drawingLight = value;
		}

		private void SetLight(Color value)
		{
			light = value;
		}
	}
}